package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````,``P`!````0A,``#0````,D0```````#0`(``(
M`"@`%P`6``8````T````-````#0``````0````$```4````$`````P```#0!
M```T`0``-`$``!<````7````!`````$````!````````````````````Y(<`
M`.2'```%`````!````$```#\C0``_)T``/R=``!$`@``>!(```8`````$```
M`@```!".```0G@``$)X``+@```"X````!@````0```!0Y71DC'H``(QZ``",
M>@``U````-0````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9/R-``#\G0``_)T```0"```$`@``!`````$````O;&EB+VQD
M+6UU<VPM:3,X-BYS;RXQ```1````3`````0````'`````($``)M$!$E(CA`A
MBH0$R`````!,````4````%0```!5````6@```%L```!<`````````%X`````
M`````````%\```!@````80``````````````:G^:?.K3[P[.WD<M;\7?'R[%
MF[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MOXD?&`;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[7^IG)OAIP(*H^#[20`````````````````````,````
M```````````2````R0$`````````````$@```!0``````````````!$```#O
M`0`````````````1````:P$`````````````$@```!L``````````````!(`
M``"H`0`````````````2````(P``````````````$@```"H`````````````
M`!(```#\`0`````````````2````M`$`````````````$@```$(#````````
M`````"$````S```````````````2````.0``````````````$@```$``````
M`````````!(````(`P`````````````2````^0(`````````````$@```($"
M`````````````!(```!'```````````````2````(@(`````````````$@``
M`$X``````````````!(```"V`@`````````````2````50``````````````
M$@```%T``````````````"````!Q```````````````2````GP(`````````
M````$@```'D``````````````!(```!_```````````````2````B```````
M````````(````/("`````````````!(```"D```````````````2````J0``
M````````````$@````T"`````````````!$```"]`@`````````````2````
M3P(`````````````$@```!@#`````````````!(```"P```````````````@
M````00(`````````````$@```*T#`````````````!(```#(`@``````````
M```1````00,`````````````$0```',"`````````````!(````N`P``````
M```````2````0P,`````````````$0```,X``````````````!(````F`P``
M```````````2````>0$`````````````$@```-<``````````````"(```#F
M```````````````2````Z@(`````````````$@```%\"`````````````!(`
M``#K```````````````2````\0``````````````(````*H"````````````
M`!(````+`0`````````````2````F0$`````````````$@```!`!````````
M`````"`````L`0`````````````2````CP(`````````````$@```(@!````
M`````````!(````R`0`````````````2````0P$`````````````$@```!T"
M`````````````!(```!Z```````````````2````+@(`````````````$@``
M`&@"`````````````!(````?`P`````````````2````20$`````````````
M$@```!`#`````````````!(```!=`0`````````````2````&`(`````````
M````$@```-<!`````````````!(```!+`P`````````````2````0`,`````
M````````(0```&0!`````````````!(````[`P``:!$``-H!```2``D`Z0$`
M`.XY```!````$@`*`.\#``"R+```G`D``!(`"0!E!```3#D``%X````2``D`
MS`,``"HG```%````$@`)`/X#``!<#P```0```!(`!@`2!```3C8``/X"```2
M``D`6`0``"\G``#:`0``$@`)`&,#``!`H````````!``%`#=`P``P2L``/$`
M```2``D`_`,``+<E```[````$@`)``0$``!'*P``2P```!(`"0`R!```"2D`
M`!D````2``D`;P,``'2P````````$``4`)(#``!=$P``,@```!(`"0`_!```
M(BD``+$````2``D`*`0``#R@```$````$0`3`%P#``!`H````````!``$P!H
M`P``0A,````````0``D`FP,``)(K```O````$@`)`+8#``!%)@``Y0```!(`
M"0!+!```TRD``'0!```2``D``&QI8G!E<FPN<V\`;W!E;F1I<@!S=&1E<G(`
M<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`;'-E96L`9V5T<&ED`'-T<F-M<`!M
M96US970`=6YL:6YK`&UE;6UO=F4`7TIV7U)E9VES=&5R0VQA<W-E<P!S=')N
M8VUP`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!O<&5N`'-T<G-T<@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;U]B87-E<P!R
M96%D;&EN:P!?7V-X85]F:6YA;&EZ90!E>&ET`&-L;W-E`%])5$U?<F5G:7-T
M97)434-L;VYE5&%B;&4`<F5A9`!?7W)E9VES=&5R7V9R86UE7VEN9F]?8F%S
M97,`<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P
M96-I9FEC`&UE;6-P>0!G971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA
M9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O
M;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UX.#8N<V\N,0!F
M<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P<FEN=&8`
M<W1R8VAR`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N
M=FER;VX`7U]S=&%C:U]C:&M?9F%I;`!?961A=&$`7U]B<W-?<W1A<G0`7V5N
M9``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210!?<W1A<G1?8P!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`
M<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D
M:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/
M5`!M>5]P87)?<&P`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]I;FET
M7V5N=@!P87)?9FEN9'!R;V<`<&%R7V-L96%N=7``````W)X```@```#\G@``
M"````$R?```(`````*````@````$H```"`````B@```(````#*````@````0
MH```"````!2@```(````&*````@````@H```"````"2@```(````**````@`
M```LH```"````#"@```(````/*````@```#4G@``!@$``-B>```&`@``X)X`
M``8#``#DG@``!@0``.B>```&!0``[)X```8&``#PG@``!@<``/2>```&"```
M^)X```8)````GP``!@H```2?```&"P``")\```8-```,GP``!@X``!"?```&
M#P``%)\```80```8GP``!A$``!R?```&$@``()\```83```DGP``!A0``"B?
M```&%0``+)\```86```PGP``!A<``#2?```&&```.)\```89```\GP``!AH`
M`$"?```&&P``1)\```8<``!(GP``!AT``%"?```&'@``5)\```8?``!8GP``
M!B```%R?```&(0``8)\```8B``!DGP``!B,``&B?```&)```;)\```8E``!P
MGP``!B8``'2?```&)P``>)\```8H``!\GP``!BH``("?```&*P``A)\```8L
M``"(GP``!BT``(R?```&+@``D)\```8O``"4GP``!C```)B?```&,0``G)\`
M``8R``"@GP``!C,``*2?```&-```J)\```8U``"LGP``!C8``+"?```&-P``
MM)\```8X``"XGP``!CD``+R?```&.@``P)\```8[``#$GP``!CP``,B?```&
M/0``S)\```8^``#0GP``!C\``-2?```&0```V)\```9!``#<GP``!D(``."?
M```&0P``Y)\```9$``#HGP``!D4``.R?```&1@``\)\```9'``#TGP``!D@`
M`/B?```&20``_)\```9+``"#[`SH.04``.A>*@``@\0,PP```/^S!````/^C
M"`````````#_HPP```!FD/^C$````&:0_Z,@````9I#_HR0```!FD/^C*```
M`&:0_Z,L````9I#_HS````!FD/^C.````&:0_Z,\````9I#_HT````!FD/^C
M1````&:0_Z-(````9I#_HTP```!FD/^C4````&:0_Z-4````9I#_HU@```!F
MD/^C7````&:0_Z-@````9I#_HV0```!FD/^C:````&:0_Z-P````9I#_HW0`
M``!FD/^C>````&:0_Z-\````9I#_HX@```!FD/^CC````&:0_Z.0````9I#_
MHY@```!FD/^CG````&:0_Z.@````9I#_HZ0```!FD/^CJ````&:0_Z.L````
M9I#_H[0```!FD/^CN````&:0_Z/`````9I#_H\0```!FD/^CR````&:0_Z/,
M````9I#_H]````!FD/^CU````&:0_Z/8````9I#_H]P```!FD/^CY````&:0
M_Z/H````9I#_H^P```!FD/^C\````&:0_Z/T````9I#_HP`!``!FD/^C!`$`
M`&:0_Z,(`0``9I#_HPP!``!FD/^C%`$``&:0_Z,8`0``9I#_HQP!``!FD/^C
M(`$``&:0_Z,D`0``9I#_HR@!``!FD/^C+`$``&:0_Z,P`0``9I#_HS0!``!F
MD(U,)`2#Y/#_<?Q5C4$(B>575E-1B<[H#`(``('#18T``(/L#%"-00104>@1
M____BX,0`0``@\0,4%#_L_P```#H._[__XN#'````(/$$(N[E````(`X`'4T
MZ)+^__^%P(F#J!$``'4*@^P,:@'HWO[__X/L#%#H!?___UG_-^A%____@\00
MQH!)!0```(/L#/\WZ#'___^`B.8"```"6O\WZ"+___^`B.8"```!BP:#Q!"#
MP`4]____/W844%"-@WN;____L[````!0Z(C]__^#[`S!X`)0Z)3^__^+?@2)
M@YP1``"#Q!#'@Z`1```$````N0$```"+%XD0C9,0GO__B5`$BY-T`0``B5`(
MC9,3GO__B5`,BQ8YT7T*BS2/B72(#$'K\H/L#,=$D`P`````@\(#:@!0C8,J
MA___4E#_LZ@1``#H=OW__X/$((7`B<9U$X/L#/^SJ!$``.C__?__@\00B<:#
M[`S_LZ@1``#HK/W__XV#R9O__^B1#@``@\00A<!U,(.[I!$```!U$8V#?IO_
M_^AV#@``B8.D$0``BX.D$0``A<!T#(/L#%#H,28``(/$$(/L#/^SJ!$``.@<
M_O__Z%_\__^#Q!"-9?")\%E;7E]=C6'\PS'MB>"#Y/!04.@`````@00DP(H`
M`%#H`````%/H+````('#98L``(/L$(M$)!AJ`/^S-````/^SA````(U0!%+_
M,/^S%````.@!_?__BQPDP^AJ`0``!3"+``"-B'@!``"-D'L!```IRH/Z!G87
MBX"`````A<!T#56)Y8/L%%'_T(/$$,G#5>@X`0``@<'ZB@``B>564XV!>`$`
M`(V9>`$``+X"````*=C!^`*9]_Z%P'03BY'@````A=)T"5%14%/_TH/$$(UE
M^%M>7<-5B>575E/H=?___X'#KHH``(/L#("[>`$```!U:8.[S`````!T$8/L
M#/^S.`$``.AM_/__@\00C;,\____C;M`____*??!_P)/BX-\`0``.<=V#$")
M@WP!``#_%(;KZN@@____@[ND`````'02C8/4W/__@^P,4.CE^___@\00QH-X
M`0```8UE]%M>7UW#5>@`````6H'")8H``(GE4U#HW/[__X'#%8H``(.[\```
M``!T&8V#@`$``%)J`%"-@]3<__]0Z!C\__^#Q!"-DT3___^#.@!T$XN#;```
M`(7`=`F#[`Q2_]"#Q!"+7?S)Z<;^__^+!"3#BPPDPU57,=)64X'L?`$``(E$
M)`AEH10```")A"1L`0``,<"+1"0(C5@<BPR3C40D+`_)B0R00H/Z$'7NC8PD
M+`$``(M0-#-0((/`!#-0!#-0_-'"B5`\.<AUZ(M$)`B+`(E$)!"+1"0(BU0D
M$(M`!,'*`HE$)!B+1"0(BTPD&(M`",')`HE$)`R+1"0(BWPD#(ML)`R+0`PQ
MSR-\)!`S?"0,B40D%(M$)`B+7"04BT`0B40D'(M$)"R+="0<C;0&F7F"6HM$
M)!#!P`4!\(MT)`PS="04(W0D&#-T)!0!QHM$)#"-A`.9>8):B<LQTP''B?`A
M\\'`!3'+P<X"`<>+1"0TC80%F7F"6HML)#@!PXGXP<`%C8PIF7F"6HML)#P!
MPXG0,?`A^,'/`C'0C90JF7F"6HML)$`!R(G9P<$%`<B)\3'Y(=DQ\8VT+IEY
M@EJ+;"1$`=&)PL'"!<'+`@'1B?HQVB'"P<@",?J-O"^9>8):BVPD2`'RB<[!
MQ@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD3`'XB=?!QP4!^(G/B?'!SP(Q^2'1
M,?&-M"Z9>8):BVPD4`'9B</!PP4!V8G3B?K!RP(QVB'"P<@",?J-O"^9>8):
MBVPD5`'RB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD6`'XB=?!QP4!^(G/
MB?'!SP(Q^2'1,?&-M"Z9>8):BVPD7`'9B</!PP4!V8G3B?K!RP(QVB'"P<@"
M,?J-O"^9>8):BVPD8`'RB<[!Q@4!\HG&B=@Q\"'(,=B-G"N9>8):BVPD9`'X
MB=?!QP4!^(G/B?'!SP(Q^2'1,?&-M"Z9>8):`=F)P\'#!0'9B=.)^L'+`C':
M(<+!R`(Q^HG%B=@!\HG.,>C!Q@4AR,')`@'RBW0D:#'8C;0WF7F"6HGO,<\!
M\(G6(=?!Q@4Q[\'*`@'PBW0D;(V<,YEY@EJ)SC'6`=^)PR'&P<,%,<[!R`(!
MWXM<)'"-G!V9>8):BVPD=`'>B?O!PP6-C"F9>8):BVPD>`'>B=,QPR'[,=/!
MSP*-E"J9>8):`<N)\<'!!0'+B<$Q^2'QP<X",<$!T8G:P<(%`=&+5"1\C800
MH>O9;HGZ,?(QVL'+`@'"B<C!P`4!PHN$)(````"-O`>AZ]ENB?`QV#'(`?B)
MU\''!0'XB<^+C"2$````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0D
MB````,'.`HV<$Z'KV6Z)^C'R,<(!VHG+P<@"P<,%`=J)PXN$)(P```"-O`>A
MZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"20````P<\"C;0.H>O9;HG9,?DQT0'Q
MB<;!Q@4!\8G6BY0DE````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)
MPXN$))@```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"2<````P<\"C;0.
MH>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DH````,'.`HV<$Z'KV6Z)^C'R,<+!
MR`(!VHG+P<,%`=J)PXN$)*0```"-O`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+
MC"2H````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6BY0DK````,'.`HV<
M$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+````"-O`>AZ]ENB?`QV#'(
M`?B)U\''!0'XB<^+C"2T````P<\"C;0.H>O9;HG9,?DQT0'QB<;!Q@4!\8G6
MBY0DN````,'.`HV<$Z'KV6Z)^C'R,<+!R`(!VHG+P<,%`=J)PXN$)+P```"-
MO`>AZ]ENB?`QV#'(`?B)U\''!0'XB<^+C"3`````P<\"C;0.H>O9;HG9,?DQ
MT0'QB<;!Q@4!\8G6BY0DQ````,'.`HV<$Z'KV6Z)^C'R,<+!R`*)Q8N$),@`
M```!VHG+P<,%`=J-G`>AZ]ENB?`QZ#'(`=B)T\')`L'#!0'8B>L)RXG?B>LA
MUR'+P<H""?N+O"3,````C;0^W+P;CXG/"=<!\XG&P<8%`?.)_HG/(<8AU\'(
M`@GWB[0DT````(VT-=R\&X\!]XG>P<8%`?>)U@G&(=[!RP*)]8G6(<8)[HNL
M)-0```"-C"G<O!N/B=V)PPGK`<Z)^2'[P<$%`<Z)V8G#(>L)RXN,)-@```"-
ME`K<O!N/B>D!T\'/`HGR"?G!P@4A\0'3P<X"B<J)Z2'Y"=&+E"3<````C800
MW+P;CXGZ"?(!P8G8P<`%`<&)T(GZ(=@A\L'+`@G"BX0DX````(V$!=R\&X\!
MPHG(P<`%`<*)\`G8(<B)Q8GP(=@)Z(NL).0```"-O"_<O!N/`?B)U\''!0'X
MB<^)V<'/`@GY(=&)S8G9(?D)Z8NL).@```"-M"[<O!N/`?&)QL'&!0'QB=:)
M^L'.`@GR(<+!R`*)U8GZ(?()ZHNL).P```"-G"O<O!N/`=J)R\'#!0':B<.)
M\`G8(<B)Q8GP(=@)Z(NL)/````"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY
M(=&)S8G9(?D)Z8NL)/0```"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<*)
MU8GZ(?()ZHNL)/@```"-G"O<O!N/`=J)R\'(`L'#!0':B<.)\`G8(<B)Q8GP
M(=@)Z(NL)/P```"-O"_<O!N/`?B)U\''!0'XB<^)V<'/`@GY(=&)S8G9(?D)
MZ8NL)``!``"-M"[<O!N/`?&)QL'&!0'QB=:)^L'.`@GR(<+!R`*)U8GZ(?()
MZHNL)`0!``"-G"O<O!N/B<6)\`GH`=J)RR'(P<,%`=J)PXGP(>@)V(N<)`@!
M``"-G!_<O!N/`=B)T\')`L'#!0'8B>L)RXG?B>LAUR'+P<H""?N+O"0,`0``
MC;0^W+P;CP'SB<;!Q@4!\XG."=:)]XG.(<<AUL'(`@G^B[PD$`$``(V\/=R\
M&X\!_HG?P<<%`?Z)UPG'(=_!RP*)_8G7(<<)[XNL)!0!``"-C"G<O!N/`?F)
M]\''!0'YB<<)WR'WB?V)QR'?">^+K"08`0``C90JW+P;CP'7B<K!S@+!P@4!
MUXN4)!P!``"-E!#6P6+*B=@Q\#'(P<D"`=")^L'"!0'0BY0D(`$``(V<$];!
M8LJ)\C'*,?K!SP(!VHG#P<,%`=J+G"0D`0``C;0>UL%BRHG+,?LQP\'(`@'S
MB=;!Q@4!\XG&BX0D*`$``(V,`=;!8LJ)^#'P,=`!R(G9P<$%`<B)T8N4)"P!
M``#!R0*-E!?6P6+*B?<QSS'?`=>)PL'"!0'7BY0D,`$``,'+`HVT%M;!8LJ)
MRC':,<+!R`(!\HG^P<8%`?*)QHN$)#0!``"-A`'6P6+*B=DQ\3'YP<\"`<&)
MT,'`!0'!BX0D.`$``(V<`];!8LJ)\#'X,=`!V(G+P<,%`=B)TXN4)#P!``#!
MRP*+;"00C906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)$`!``"-O!?6P6+*
MB=HQRC'"P<@"`?J)]\''!0'ZB<>+A"1$`0``C80#UL%BRHG+,?LQ\\'.`@'#
MB=#!P`4!PXN$)$@!``"-C`'6P6+*B?@Q\#'0`<B)V<'!!0'(B=&+E"1,`0``
MP<D"C907UL%BRHGW,<\QW\'+`@'7B<+!P@4!UXN4)%`!``"-M!;6P6+*B<HQ
MVC'"P<@"`?*)_L'&!0'RB<:+A"14`0``C80!UL%BRHG9,?$Q^<'/`@'!B=#!
MP`4!P8N$)%@!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=.+E"1<`0``P<L"
MC906UL%BRHG^,=XQSL')`@'6B<+!P@4!UHN4)&`!``"-O!?6P6+*B=HQRC'"
MP<@"`?J)]\''!0'ZB[PD9`$``(V\.];!8LJ)RS'#,?/!S@(!^XG7P<<%`?N+
MO"1H`0``C;P]UL%BR@'/B<$Q\0-T)!0QT<'*`@-4)`P!^8G?`UPD&,''!0'Y
M`T0D'(M\)`B)#XE?!(E'$(E7"(N$)&P!``!E,P44````B7<,=`7HT1@``('$
M?`$``%M>7UW#55=64S'VZ)SR__^!P]5]``"#[!R%P'1NBXN\````B<6+,8ET
M)`0Q]H-\)`0`=%>*30"$R70(@/D]=`-%Z_&+?"0$B<$IQ8LWA?9T.HE4)`Q0
M55&)3"045NC;[O__@\00A<"+3"0(BU0D#'45@#PN/74/*WPD!(UT+@'!_P*)
M.NL%@\<$Z\"#Q!R)\%M>7UW#@^P<C50D"&6+#10```")3"0,,<GH5____XM,
M)`QE,PT4````=`7H"Q@``(/$',-75NC\%P``@<(:?0``4XG#@^P0B[J\````
M9:$4````B40D##'`C70D"(GRB=CH#____X7`=!>+!XM4)`B-!)"+4`2%THD0
M=.&#P`3K\HM$)`QE,P44````=`7HJ!<``(/$$%M>7\-55U93@^PL_.AU\?__
M@<.N?```B00DB50D!&6A%````(E$)!PQP#'`@#H]C50D&`^4P`%$)`2#S?^+
M?"0$,?:)Z8GP\J[WT8U!_XE$)`B+!"3HA?[__X7`=#&)Z8G'B<*)\/*NB<WW
MU4TY;"0(#X>L````,<"+7"0$B@P#B`P"0(3)=?$QP.D0`0``BX.\````,>V+
M$(,\J@!T`T7K]X.[F!$```"-=0)T(\'F`E%15E+HU>S__XN3O````(/$$(7`
MB0)U1H/(_^G.````B50D#,'F`H/L#%;'@Y@1```!````Z!SM__^#Q!"%P(G'
M=-6#[@A05HM4)!125^@+[?__BX.\````@\00B3B+@[P```"+`,=$J`0`````
MB6PD&(L$)(H0A-)T"(#Z/70#0.ORB[.\````BTPD&(/L#"M$)`R+%HT\BHM,
M)!2-1`$"4.BO[/__@\00A<")!P^$9/___XL&BU0D&(L$D/\$)(LT)(I6_X32
MB!!T"(#Z/70#0.OIQ@`],=*+?"0$B@P7B$P0`4*$R77PZ>G^__^+7"0<93,=
M%````'0%Z/05``"#Q"Q;7E]=PU575E.![(P```#\Z+WO__^!P_9Z``")QF6A
M%````(E$)'PQP(7V#X08`0``@#X`#X0/`0``@^P,5NB`Z___@\00A<")Q0^$
M^0```(V#-9O__XE$)`B-@S2;__^)1"0,@^P,5>BVZ___@\00A<`/A+T```"#
MP!.)!"124O]T)!#_="0,Z([K__^#Q!"%P'304%#_="04_W0D#.AXZ___@\00
MA<!TNH/*_S'`B?>)T8/L#/*NBWPD#/?1B4PD$(G1BU0D$/*NB<CWT(T,`E'H
M?.O__XG'C8,WF____W0D$%905^B0[/__@\08C40D)%!7Z&+L__^#Q!!`=!F+
M1"0L)0#P```]`$```'4)B?CH[_[__^L,@^P,5^@JZ___@\00@^P,5^@F[/__
M@\00Z2____^#[`Q5Z#WK__^)-"3H]>O__X/$$(M$)'QE,P44````=`7HEA0`
M`('$C````%M>7UW#5U:)QE/H8N[__X'#FWD``(/L#(N[E````/\WZ.WK__]:
M604D`0``4%;HW^K__X/$$(7`=`0QP.M7@^P,_S?HRNO__XN`-`$``(/$$"4`
M\```/0!```!U%U!0:@)6Z"/J__^#Q!"%P`^4P`^VP.LA@^P,_S?HE.O__XN`
M-`$``(/$$"4`\```/0"@``!UI^O(6UY?PU/HTNW__X'#"WD``(/L%(N#E```
M`/\PZ%WK__^-D[C;__]2C9,]F____[/X````4E#H,^O__X/$*%O#5E/HENW_
M_X'#SW@``(/L$(NSE````/\VZ"'K__^)!"3HH/___UC_-N@1Z___6HV3#Y[_
M_UEJ`%)2C9.&E___4HV369O__U)0Z'GI__^#Q"1;7L-55U93Z$'M__^!PWIX
M``"![!P@``!EH10```")A"0,(```,<#H8NG__XV3;IO__X/L#%)0C8-RF___
M4&@!$```C70D)E;H(>G__XU0`8/$(('Z`1```'8"#PN%P'D$,?;K85)H`!``
M`(VL)!,0``!55NC=Z?__@\00A<")QWC?C4`!@^P,4.A`Z?__@\00A<")QG3*
M.>AS!XT$.#G%<KDY[G8(C40]`#G&<JV!_P$0``!_I5!755;H/^K__\8$/@"#
MQ!"+C"0,(```93,-%````(GP=`7HCQ(``('$'"```%M>7UW#Z1;___]55U93
M@>PL$```_.A0[/__@<.)=P``BY0D1!```(NT)$`0``!EH10```")A"0<$```
M,<"-@WZ;__^)%"3H"/K__XG%4%!J+U;H[.C__X/$$(7`BQ0D=!*-@X>;__^)
M\NAZ^O__Z4\!```QP(/)_XGW\J[WT8U!_XE$)`104(V#E)O__U!2Z&_I__^)
MPHV#-9O__X/$$(E$)`B+@Y0```")!"2%TG2Q@#H`=02+5"0(A>UT'%=74HE4
M)!A5Z.GG__^#Q!"%P(M4)`P/A,\````QP(/)_XG7\J[WT4F`?`K_+W4'2<8$
M"@#K\HM$)`2-1`$!/?\/```/CUO___^-@Y:;__]14590C8.NG/__4E!H`!``
M`(U\)#A7Z&3G__]`@\0@/0`0``!V`@\+@^P,BT0D#/\PZ,GH__]96@4D`0``
M4%?HH^C__X/$$(7`=5&#[`R+1"0,_S#HINC__XN`-`$``(/$$"4`\```/0"`
M``!U+E)2:@%7Z/_F__^#Q!"%P'4=C8.'F___B?KH4/G__X/L#%?H>N?__X/$
M$(G&ZQI04(V#E)O__U!J`.A+Z/__@\00B<+IZO[__XGPB[0D'!```&4S-10`
M``!T!>BP$```@<0L$```6UY?7<.+1"0$C5`!BDK_A,ET"H#Y+W4"B=!"Z^_#
M55=64X/L#/R+="0@Z%SJ__^!PY5U``"%]G0VBA:$TG0P,<"#R?^)]_*N]]&-
M1`[^.<9S%(`X+W4(2.OT2#G&<P>`."]U]NLM.<9U*8#Z+W4+@^P,C8,UF___
MZPF-@Y:;__^#[`Q0Z+/F__^#Q!#K.8`X+W4%2#G&<O8I\(U0`H'Z`!```'<@
M0#T`$```=@(/"U)05HVSF`$``%;HWN;__X/$$(GPZP(QP(/$#%M>7UW#5U93
M@^PP_.BPZ?__@</I=```9:$4````B40D+#'`C8.8F___C7PD"HVSE-O__[DB
M````\Z3HFO?__XV#H9O__^B/]___C8.IF___Z(3W__^-@[*;___H>??__XV#
MN9O__^AN]___C8/)F___Z&/W__^-@WZ;___H6/?__XV#U9O__^A-]___C8/?
MF___Z$+W__^-@^F;___H-_?__XV#AYO__^@L]___C8/SF___Z"'W__^-@_R;
M___H%O?__XV#!YS__^C<]O__A<!T#8G"C8/?F___Z&#W__^-@QB<___HP/;_
M_X7`=`V)PHV#*IS__^A$]___C8,UG/__Z*3V__^%P'0*B<*-@WZ;___K-HV#
M19S__^B+]O__A<")PG4?C40D&U*-DU:<__]J"E)0Z!GE__^#Q!"%P'4/C50D
M)8V#U9O__^CP]O__C9-AG/__C8.YF___Z-_V__^+1"0L93,%%````'0%Z&X.
M``"#Q#!;7E_#4^A"Z/__@<-[<P``@^P(@[MP`0``_W4HC8/5F___Z`[V__\Q
MTH7`=`Z*`(3`#Y7"/#`/E<`AP@^VTHF3<`$``(N#<`$``(/$"%O#4^CWY___
M@<,P<P``@^P(Z+KE__^#[`Q0Z-'D__^#Q!`QTH7`=`*+$(/$"(G06\-55U93
M@^P\_(M$)%"Y!P```.BXY___@</Q<@``C7PD$(D$)(VS/`$``&6A%````(E$
M)"PQP(U$)!#SI8E$)`2-@Y2;__^)1"0(C8.NG/__B40D#(M$)`2+*(7M='J)
MZ.A3]?__A<")QG0%@#@`=06+%"3K4E!0_W0D"%;H#^3__X/$$(7`=4:+/"2#
MR?^#[`SRKHGWB<J#R?_RKO?2B<CWT(T,`E'HI>/__XDT)/]T)!B)Q_]T)!3_
M="0D4.BVY/__@\0@B?J)Z.A_]?__@T0D!`3I?/___XM$)"QE,P44````=`7H
M!`T``(/$/%M>7UW#55=64X'L#($``/SHS>;__X'#!G(``&6A%````(F$)/R`
M```QP(V#CYS__XNL)""!``#'1"0T`````(U\)$2-LU@!``"Y!@```(E$)"R-
M@S6;___'1"1``````/.EB40D,(V#E)S__XE$)#B-@YF<__^)1"0\C8-^F___
MZ$;T__^%P'0A@#@`B<9T&H/L#%#H>_[__XDT).CRXO__B40D%.F=`P``Z#;^
M__^%P(G&C7PD.'4SBP>%P'0GZ`?T__\Q]H7`=!.`.`!T#H/L#%#HN^+__X/$
M$(G&@\<$A?9TU>L&C;.(G/__,<")]X/)__*N@^P,]]&-1`G_4.A?XO__B40D
M%(/$$(M\)`2-DZ*<__^`/@!T'5$/M@9&4%*)5"045X/'`NA=X___@\00BU0D
M".O>C7PD1(LWA?9T*8GPZ(/S__^%P(G&="*`.`!T'>@>]___A<!T%(/L#%;H
M+N+__X/$$(G&C7PD+.LT@\<$Z\:+%X72="V`.@!T*(G0B50D".CK]O__A<"+
M5"0(=`Z#[`Q2Z/?A__^#Q!")QH/'!(7V=,TQP(/)_XGW\JZ+?"0$@^P,]]&)
MRH/)__*NB<CWT(V\`@($``!7Z)'A__^)1"086(V#IYS__UK_="0,4(V#EIO_
M_XE$)!Q0C8.LG/__5E#_="0DZ(SB__^#Q!AHP`$``/]T)!3H2^+__X/$$$!U
M-^@XXO__@S@1="WH+N+__X/L#/\PC8.UG/___W0D&/]U`%"+@Q@```#_,.C.
MX?__@\0@Z2@'``"+LY0```"#[`S_-N@FXO__6ED%)`$``%#_="04Z!7A__^)
M1"0@@\00@WPD$``/A=<&``"#[`S_-NCYX?__BX`T`0``@\00)0#P```]`$``
M``^%M`8``(/L#/\VZ-;A__^+@#P!``")1"04Z/?A__^#Q!`Y1"0$#X6.!@``
M@^P,_S;HL.'__XN`-`$``(/$$"7_`0``/<`!```/A6L&``"#[`Q7Z&[@__^)
M1"04C8-FG/__Z,?Q__^#Q!"%P`^$0`$``(/L#%#H>^#__UI94/]U`.A?]___
M@\00A<")Q@^$'P$``#'`@\G_B??RKO?1C7G_@_\##X\0`0``Z$[[__^%P(E$
M)!0/A6\%``!75VH`5N@YX/__@\00A<")Q@^$6`4``&H":O]J[E#HH-___X/$
M#&H&C;PD!`$``%=6Z*7@__^#Q!"`O"3\``````^%+0$``("\)/T```!##X4?
M`0``@+PD_@```$$/A1$!``"`O"3_````0P^%`P$``("\)``!``!(#X7U````
M@+PD`0$``$4/A><```!J`FK_:L96Z"K?__^#Q`QJ*5=6Z#;@__^-@P^>__]9
M7E!7_W0D'(V#^IS___]T)!Q0_W0D(.ALX/__@\0@@^P,_W0D%.@UX/__BU0D
M%(V#?IO__^@C\?__6/]T)!#HS?K__X/$$.DN!0``BW4`Z=G^__]04(V#\)S_
M_U"-1`[[4.C!WO__@\00A<`/A=+^__^#_P1T"X!\/OLO#X7"_O__BVT$A>T/
MA+?^__\QP(/)_XGO\J[WT8U!_X/X`P^&H/[__U!0C8/UG/__4(U$#?M0Z''>
M__^#Q!"%P`^%@O[__XGNZ7O^__]J`&H`:@!6Z$/>___'1"1L`2-%9\=$)'")
MJ\WOQT0D=/[<NIC'1"1X=E0R$,=$)'SPX=+#QX0D@`````````#'A"2$````
M`````,>$),@`````````@\00C80D_````(E$)!"-1"1XB40D#%=H`(```/]T
M)!A6Z.S>__^#Q!"%P(G'#XY%`0``C03]``````-$)'!S!/]$)'2)1"1PB?C!
MZ!T!1"1TBX0DN````(7`='6Y0````(G]*<$YSWX"B<T#1"0,.T0D$',)C0PH
M.4PD$'(0.T0D$'8,BTPD$`'I.<AS`@\+@?T`@```=_925?]T)!A0Z,[>__^+
MA"3(`````>B)A"3(````@\00@_A`#X56____C40D7"GO`VPD$.AMXO__ZP>-
MK"3\````C80DN````(E$)!R#_S]^1#ML)`QV!CML)!QRFCML)`QS"8U%0#E$
M)`QRBU!J0(/O0%6#Q4"-1"1HB40D)/]T)!CH5-[__XM$)"CH%>+__X/$$.NW
M.VPD#'8.BT0D#`'X.<4/@D[___\[;"0,<PZ-1#T`.40D#`^".O___X/_1`^'
M,?___U!75?]T)!CH"=[__XF\),@```"#Q!#IGO[__X/L#%;H@=W__XNL)(``
M``"+M"2$````B>K!Z@.#XC^-0@'&A!2(````@(/$$(/X.'XUND````!1*<)2
M:@"-O"2$````C4PD:`'XB4PD&%#H7MS__XM$)!SH9^'__X/$#&HX:@!7ZQ-2
MNC@````IPE)J`(V$!(0```!0Z#/<__^)\(/$$,'H&(B$)+````")\,'H$(B$
M)+$```")\,'H"(B$)+(```")\(VT)-,```"(A"2S````B>C!Z!B)]XB$)+0`
M``")Z,'H$(B$)+4```")Z,'H"(B$)+8```")Z(VKHIS__XB$)+<```"-1"1<
MZ-#@__^+1"1<B<*(A"3"````P>H8B)0DOP```(G"P>H0B)0DP````(G"BT0D
M8,'J"(B4),$```")PHB$),8```#!ZAB(E"3#````B<+!ZA"(E"3$````B<*+
M1"1DP>H(B)0DQ0```(G"B(0DR@```,'J&(B4),<```")PL'J$(B4),@```")
MPHM$)&C!Z@B(E"3)````B<*(A"3.````P>H8B)0DRP```(G"P>H0B)0DS```
M`(G"BT0D;,'J"(B4),T```")PHB$)-(```#!ZAB(E"3/````B<+!ZA"(E"30
M````B<+!Z@B(E"31````C90DOP```%"+1"08B50D$`^V!!!055:#Q@+H]-O_
M__]$)"2#Q!"#?"04%(M4)`QUUHV##Y[__\:$)/L`````5550C8.6F___5U#I
M1/O__XV389S__XV#U9O__XV[%YW__^B"[/__Z$#:__]65HVS#Y[__U90C8,)
MG?___W0D'/]T)!Q0_W0D(.B&V___@\0@4E)HP`$``/]T)!#H0]O__X/$$$`/
MA0#[___H+-O__X,X$0^%\OK___]$)!#HZMG__U%6_W0D&%#_="0<_W0D'%?_
M="0@Z#G;__^#Q"#KL8V#*)W___]T)`C_=0!0BX,8````_S#HH=K__X/$$,=$
M)`0`````BXPD_(```&4S#10```"+1"0$=`7H:P,``('$#($``%M>7UW#55=6
M4^@XW?__@<-Q:```@^PHB[.4````_S;HP]K__UW_-HG'Z+G:__^*0&"(1V&-
M@[F;___H\.K__X/$$(7`=`N`.#%U!H!X`0!T!>@T\___@^P,_S;HA]K__XV3
MAYW__VH+:@%24.BFV?__@\0@A<!U+8/L#/\VZ&7:__^-DXR=__]J`VH!4E#H
MA-G__X/$((7`B<</A<X```#I#0$``(M`#+\!````BV@8.[N@$0``C4?_B40D
M"'T>@^P,_S;H'MK__VH`_W0D'%50Z-'8__^#Q""%P'48BX.@$0``OP$```")
M1"0,2#E$)`AUA>M4BQ"+0@@E``0@`#T`!```=06+0@SK((E4)`R#[`S_-NC.
MV?__:@)J`(M4)"124.C?V?__@\0@45%0BX.<$0``_S2XZ%/8__^#Q!"%P'6:
M1^EG____.[N@$0``#XTC____@^P,_S9'Z(?9__]96E50Z-;7__^#Q!#KVXM`
M#(/L#(LH_S;H:MG__XV3CIW__X/$#%)54.BAV/__BT<,@\00BSCV1PI`=!:#
M[`S_-NA!V?__75I74.@(V/__@\00@^P,_S;H*]G__XV3!9S__VH#:@%24.A*
MV/__@\0@A<")Q71GC8.'F___Z$[I__^%P(G'=`6+10SK-^@+[O__A<")QXM%
M#'0A@^P,BRC_-NCAV/__@\0,5U50Z![8__^)/"3HKMC__^L?BY.<$0``BSJ+
M*(/L#/\VZ+C8__^#Q`Q755#H]=?__X/$$(/L#/\VZ*#8__^-DY.=__^#Q`QJ
M`5)0Z/[6__]:_S:)Q^B$V/__C9.HG?__@\0,4E=0Z+O7__]9_S;H:]C__\9`
M80"-@WZ;___HI.C__X/$$(7`B8.D$0``=2:#[`S_LYP1``#HP_/__X/$$(7`
MB8.D$0``=0N#[`R-@ZZ=___K-U!0:,`!``#_LZ01``#H[]?__XU0`8/$$(/Z
M`78@@_@1=!M0BX.<$0``_[.D$0``_S"-@\^=__]0Z'S6__^#Q!Q;7E]=PU=6
M4XMT)!#H-]K__X'#<&4``(/L#%;HN^___XD$).B:[___@\00B<?HSO'__X7`
M="F%]G0E@#X`="!04(V#IYS__U!7Z+O6__^#Q!`YQW4*6XGP7E_I'.K__UM>
M7\.+%"3#4^C;V?__@<,490``@^P(Z);7__^#Q`A;PU7H-=O__P7[9```B>53
M4HV8./___X/K!(L#@_C_=`3_T.OR6%M=PX/L#.@9VO__@\0,PP``+BX`)7,O
M)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4`&5X90`O<')O8R\E:2\E<P!005)?5$5-4`!005)?4%)/1TY!344`
M.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE4
M24%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#
M04-(10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%2
M7T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$E"4$%42`!$64Q$7TQ)0E)!
M4EE?4$%42`!32$Q)0E]0051(`%-94U1%30`O=&UP`%5315(`55-%4DY!344`
M)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U
M8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`<&%R;``N<&%R`"5S
M)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`E
M<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@
M<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`%1%35!$25(`
M5$U0`$%21U8`&`!P97)L`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#,U`%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D
M>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L
M;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L
M($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I
M<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@
M(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@
M+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P
M87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G
M*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M
M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D
M:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@
M)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O
M"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[
M('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*
M<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M
M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U
M=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C
M;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN
M=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI0
M05(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@
M)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%2
M1U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?
M05)'0WT@+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF
M;W(@*&ME>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'
M5E\O.PI]"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*
M;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@
M/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S
M:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R
M(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM
M>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E
M860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]
M/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD[
M"FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F
M9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S
M<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M
M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F
M9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI
M<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L
M;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA
M;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E
M>'0L("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D
M;W5T("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*
M?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD
M(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D
M14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F
M:6QE;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@
M9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E
M("1O=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@
M)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q
M=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y
M(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@
M9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B
M+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP
M9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I
M;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO
M<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*
M=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES
M="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@
M>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@
M("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*
M=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G
M+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@
M/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@
M97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2![
M"G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2![
M"B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G
M<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<[
M"GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D
M,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8
M.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2![
M"B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R
M(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H
M*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A
M<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`]
M(%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@
M;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES
M(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B
M.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/
M3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D
M(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<
M)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R
M(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA
M<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@
M(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC
M*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@
M/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM
M>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE
M(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI
M7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L
M<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@
M)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A
M8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*
M<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\
M)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO
M9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R
M:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I
M;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]
M"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM
M;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]
M"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[
M"B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D
M0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A
M;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP
M('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O
M<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)
M4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T
M;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I
M9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]
M("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*
M)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#
M;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY
M("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R
M96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2![
M"G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U
M9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI6
M15)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@
M)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G
M;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O
M<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C
M='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.
M5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H)&9H
M+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT
M(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE(&EF
M("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]"F5L
M<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL96YA
M;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I
M("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?
M("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T
M92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?
M1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A
M;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U
M=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L
M;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I
M;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F
M:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP
M('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H
M97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!0
M05(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R
M="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ
M97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ
M97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<
M*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?
M"@```%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````'!E<FQX
M<VDN8P````$;`SO0````&0```.24___L````W);__]P,``!^FO__$`$``%RF
M__]0`0``[*;__YP!```;I___M`$``(&G___H`0``-JG__U@"``"7JO__(`,`
M`"NK__^$`P``9JO__[0#``"YJ___``0``)ZL__^,!```HZS__Z`$``!]KO__
MG`4``):N__^P!0``1Z___PP&``"[L/__4`8```:Q__]P!@``-;'__YP&```F
MLO___`8``,*[__\$"P``P+[__X@,```>O___(`T``"*___\T#0``%```````
M```!>E(``7P(`1L,!`2(`0``(````!P```#PD___$``````."$8.#$H/"W0$
M>``_&CLJ,B0B/````$````!FF?__W@L```!!#@B%`D$.#(<#0PX0A@1!#A2#
M!48.D`,#S0L.%$'##A!!Q@X,0<<."$'%#@0``$@```"`````!*7__Y``````
M00X(A0)!#@R'`T$.$(8$00X4@P50#C!]#C1!#CA!#CQ%#D!(#C!I#A1#PPX0
M0<8.#$''#@A!Q0X$```4````S````$BE__\O`````$,.(&L.!``P````Y```
M`%^E__]F`````$$."(<"00X,A@-,#A"#!$4.(`)/#A!!PPX,0<8."$''#@0`
M;````!@!``"1I?__M0$```!!#@B%`D$.#(<#00X0A@1!#A2#!4,.0`*G#D1!
M#DA!#DQ!#E!.#D!8#DQ!#E!2#D!*#D1!#DA%#DQ!#E!.#D!T#DQ2#E!(#D`"
M60X40<,.$$'&#@Q!QPX(0<4.!````,0```"(`0``UJ;__V$!````00X(A0)!
M#@R'`T$.$(8$00X4@P5&#J`!;@ZL`4$.L`%(#J`!80ZL`4$.L`%(#J`!3PZD
M`4$.J`%$#JP!1`ZP`4@.H`%%#J0!00ZH`40.K`%$#K`!2`Z@`5`.K`%<#K`!
M40ZT`4$.N`%!#KP!00[``4@.J`%%#JP!00ZP`4@.H`%?#JP!00ZP`4@.H`%#
M#JP!00ZP`4@.H`%(#JP!00ZP`5`.H`%8#A1!PPX00<8.#$''#@A!Q0X$8```
M`%`"``!OI___E`````!!#@B'`D$.#(8#0PX0@P1.#AQ(#B!&#AQ!#AA&#AQ!
M#B!(#A!+#AQ"#B!.#A!-#A1!#AA"#AQ!#B!(#A!-#AQ"#B!.#A!/PPX,0<8.
M"$''#@0``"P```"T`@``GZ?__SL`````00X(@P).#AQ(#B!,#B1,#BA!#BQ!
M#C!(#@A!PPX$`$@```#D`@``JJ?__U,`````00X(A@)!#@R#`TX.'$@.($X.
M'$(.($8.'$<.&$(.'$$.($$.)$<.*$<.+$$.,$@.#$'##@A!Q@X$``"(````
M,`,``+&G___E`````$$."(4"00X,AP-!#A"&!$$.%(,%40ZP0%T.O$!!#L!`
M00[$0$<.R$!%#LQ`10[00$L.L$!3#K1`10ZX0$@.O$!!#L!`2`ZP0$P.O$!!
M#L!`2`ZP0&8.M$!!#KA`00Z\0$$.P$!,#K!`70X40<,.$$'&#@Q!QPX(0<4.
M!!````"\`P``"JC__P4`````````^````-`#``#[I___V@$```!!#@B%`D$.
M#(<#00X0A@1!#A2#!48.P"!Z#L0@00[(($(.S"!!#M`@2`[`(&P.Q"!!#L@@
M1P[,($$.T"!0#L`@7P[$($$.R"!!#LP@10[0($@.P"`"0`[$($$.R"!!#LP@
M00[0($<.U"!!#M@@10[<($4.X"!)#L`@3`[,($8.T"!&#LP@00[(($8.S"!!
M#M`@2`[`($<.S"!&#M`@3@[`($T.Q"!!#L@@0@[,($$.T"!(#L`@5`[,($$.
MT"!(#L`@10[$($$.R"!'#LP@0@[0($@.P"!D#A1!PPX00<8.#$''#@A!Q0X$
M````$````,P$``#9J/__&0````````!8````X`0``-ZH__^Q`````$$."(4"
M00X,AP-!#A"&!$$.%(,%0PX@`DT*#BQ("TD.+$$.,$@.(&0.)$$.*$$.+$<.
M,$@.($D.%$'##A!!Q@X,0<<."$'%#@0``$`````\!0``,ZG__W0!````00X(
MAP)!#@R&`T$.$(,$0PY``Q\!#D1(#DA!#DQ!#E!(#D!Y#A!!PPX,0<8."$''
M#@0`'````(`%``!CJO__2P````!!#@B#`DX.$'H."$'##@0H````H`4``(ZJ
M__\O`````$$."(,"3@X02`X<00X@2`X02PX(0\,.!````%P```#,!0``D:K_
M__$`````00X(A0)!#@R'`T$.$(8$00X4@P5##E`";@Y400Y81`Y<00Y@2`Y0
M30Y<50Y@3`YD1@YH1`YL00YP2`Y0:`X40<,.$$'&#@Q!QPX(0<4.!`0$```L
M!@``(JO__YP)````00X(A0)!#@R'`T$.$(8$00X4@P5&#J""`@*$"@ZL@@)!
M#K""`E8+:`ZL@@)!#K""`D@.H(("70ZL@@)'#K""`DP.H(("4`ZD@@)%#JB"
M`D$.K(("10ZP@@)+#J""`FX.K(("00ZP@@)(#J""`FX.K(("00ZP@@)(#J""
M`ED.K(("50ZP@@)*#JR"`D<.J(("1`ZL@@)!#K""`DL.M(("1PZX@@)!#KR"
M`D0.P(("2`ZH@@)%#JR"`D0.L(("2`Z@@@)5#JR"`D(.L(("2@ZT@@)##KB"
M`D$.O(("2`[`@@)(#J""`DX.K(("0@ZP@@)&#JR"`D$.J(("1@ZL@@)$#K""
M`DP.H(("3@ZL@@)"#K""`DX.H(("4PZL@@)"#K""`E<.H(("30ZL@@)"#K""
M`DX.H(("4PZL@@)!#K""`E<.H(("2PZL@@)!#K""`D8.K(("00ZH@@)!#JR"
M`D,.L(("2`Z@@@)S#J2"`D$.J(("0@ZL@@)!#K""`D@.H(("3`ZD@@)"#JB"
M`D(.K(("00ZP@@)(#J2"`D(.J(("2`ZL@@)!#K""`D@.H(("`E8.I(("0@ZH
M@@)"#JR"`D$.L(("2`ZD@@)"#JB"`D$.K(("00ZP@@),#JR"`D$.J(("00ZL
M@@)!#K""`D0.M(("2@ZX@@)!#KR"`D0.P(("2`Z@@@)##JR"`D0.L(("50ZL
M@@)$#K""`D@.H(("3@ZD@@)!#JB"`D<.K(("10ZP@@)(#J""`GL.I(("00ZH
M@@)'#JR"`D4.L(("2`Z@@@)1#J2"`D(.J(("0@ZL@@)!#K""`@)1#J""`E0.
MI(("10ZH@@)$#JR"`D$.L(("2`Z@@@("<`ZD@@)!#JB"`D0.K(("00ZP@@)8
M#J""`@)-#J2"`D(.J(("1`ZL@@)/#K""`E$.H(("=`ZD@@)!#JB"`D$.K(("
M1`ZP@@)/#J""`D@*#JR"`D$.L((":0Z@@@)+#J2"`D,.J(("0@ZL@@)2#K""
M`E$.I(("0@ZH@@)"#JR"`D$.L(("0@M!#J2"`D@.J(("0@ZL@@)(#K""`DH.
MH(("`V,!"@ZD@@)-#JB"`D$.K(("00ZP@@)/#J""`EH.I(("00ZH@@)!#JR"
M`D<.L(("00ZT@@)%"UT.I(("00ZH@@)'#JR"`D$.L(("2@ZT@@)$#KB"`D$.
MO(("1`[`@@)(#J""`D$.I(("00ZH@@)%#JR"`D0.L(("2`Z@@@)?#J2"`D$.
MJ(("1`ZL@@)!#K""`D0.M(("1`ZX@@)!#KR"`D0.P(("2`Z@@@),#J2"`D,.
MJ(("00ZL@@)(#K""`D@.H(("9PX40<,.$$'&#@Q!QPX(0<4.!(`!```T"@``
MMK#___X"````00X(A0)!#@R'`T$.$(8$00X4@P5.#CQ(#D!&#CQ"#D!;#C!7
M#CQ"#D!-#D1"#DA!#DQ!#E!(#C!'#CQ"#D!-#D1"#DA!#DQ!#E!(#C!L#CQ"
M#D!'#D1$#DA!#DQ!#E!(#C!Y#CQ"#D!'#D1"#DA%#DQ!#E!(#C!!#C1!#CA!
M#CQ)#D!(#C!9#CQ"#D!'#CQ!#CA!#CQ!#D!(#C!(#CQ$#D!.#C1!#CA!#CQ!
M#D!+#C!+#CQ"#D!&#CQ!#CA!#CQ!#D!(#C!##CQ"#D!-#D1"#DA!#DQ!#E!(
M#C!M"@X\1`Y`2`XT00XX00X\00Y`3PM-#CQ"#D!(#C1!#CA!#CQ!#D!(#C!#
M"@X\0@Y`3@XT0@XX00X\00Y`1@X\0@Y`4`XT00XX00X\00Y`1@X\0@Y`5PXP
M30X\1@Y`2`XP30X\2`M!#C1!#CA%#CQ&#D!+#C!+#C1,#CA"#CQ'#D!%#C!#
M#A1!PPX00<8.#$''#@A!Q0X$``!0````N`L``#"R__]>`````$$."(<"00X,
MA@-!#A"#!%(.'$$.(%`.$%4.%$$.&$<.'$$.($@.$$4*PPX,0\8."$''#@1%
M"T'##@Q!Q@X(0<<.!`!`````#`P``/B)___:`0```$0,`0!*$`4"=0!&#P-U
M<`80!P)U?!`&`G5X$`,"=70#O@'!#`$`0<-!QD''0<5##`0$`!````!0#```
M]K'__P0`````````'````&0,``#FL?__&0````!!#@B#`DX.$$@."$'##@0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````_____P````#_____
M```````````!`````0````$```#7`@``#P```'0#```,````7`\```T```#N
M.0``]?[_;TP!```%````*`@```8````(`@``"@```'$$```+````$````!4`
M`````````P```,B>```1````G`P``!(```#``@``$P````@````8````````
M`/O__V\!```(^O__;Q``````````````````````````````````````````
M````````````````$)X```````````````````````!H$0``````````````
M`````````````````````````.XY````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````7`\`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````*```#4[```K.P``.#L``"X[```S.P``13L```````#R.@``
MZSH``$,\```(.P``2SP```````#_____WCP``$=#0SH@*$%L<&EN92`V+C(N
M,2D@-BXR+C$@,C`Q-C`X,C(``"YS:'-T<G1A8@`N:6YT97)P`"YG;G4N:&%S
M:``N9'EN<WEM`"YD>6YS='(`+G)E;"YD>6X`+FEN:70`+G!L=``N<&QT+F=O
M=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM
M96YT````````````````````````````````````````````````````````
M```+`````0````(````T`0``-`$``!<```````````````$`````````$P``
M`/;__V\"````3`$``$P!``"\`````P`````````$````!````!T````+````
M`@````@"```(`@``(`8```0````!````!````!`````E`````P````(````H
M"```*`@``'$$``````````````$`````````+0````D````"````G`P``)P,
M``#``@```P`````````$````"````#8````!````!@```%P/``!<#P``$0``
M`````````````0`````````\`````0````8```!P#P``<`\``!``````````
M`````!`````$````00````$````&````@`\``(`/``#H`0`````````````(
M`````````$H````!````!@```&@1``!H$0``AB@``````````````0``````
M``!0`````0````8```#N.0``[CD```P```````````````$`````````5@``
M``$````"````_#D``/PY``".0``````````````$`````````%X````!````
M`@```(QZ``",>@``U```````````````!`````````!L`````0````(```!@
M>P``8'L``(0,``````````````0`````````=@````$````#````_)T``/R-
M```(```````````````$`````````'T````!`````P````2>```$C@``"```
M````````````!`````````"$`````0````,````,G@``#(X```0`````````
M``````0`````````B0````8````#````$)X``!".``"X````!``````````$
M````"````$4````!`````P```,B>``#(C@``.`$`````````````!`````0`
M``"2`````0````,`````H````)```$````````````````0`````````F```
M``@````#````0*```$"0```T$``````````````@`````````)T````!````
M,`````````!`D```(P```````````````0````$````!`````P``````````
;````8Y```*8```````````````$`````````
